@@ -492,7 +492,7 @@ int bapp_sendmessage(struct queryhash *qh, int s, int retries, int xdelay, int s
 	return(1);
 }
 
-int bapp_processmessages(int s, struct queryhash *qh)
+int bapp_processmessages(int s, struct queryhash *qh, int hexdump)
 {
 	for(;;)
 	{
@@ -597,7 +597,7 @@ int bapp_processmessages(int s, struct queryhash *qh)
 							printf("%s:%dms:", inet_ntoa(sa.sin_addr), delay);
 							braa_OID_ToString((oid*) name->pdata, buffer, 500);
 							printf("%s:", buffer);
-							braa_ASNObject_ToString(value, buffer, 500);
+							braa_ASNObject_ToString(value, buffer, 500, hexdump);
 							printf("%s\n", buffer);
 						}
 					}
@@ -646,7 +646,7 @@ int bapp_processmessages(int s, struct queryhash *qh)
 							printf("%s:%dms:", inet_ntoa(sa.sin_addr), delay);
 							braa_OID_ToString((oid*) name->pdata, buffer, 500);
 							printf("%s:", buffer);
-							braa_ASNObject_ToString(value, buffer, 500);
+							braa_ASNObject_ToString(value, buffer, 500, hexdump);
 							printf("%s\n", buffer);
 							if(q->latest_oid[walkid])
 								braa_OID_Dispose(q->latest_oid[walkid]);
