@@ -63,7 +63,7 @@ struct queryhash
 struct queryhash * bapp_make_hash(int version, struct query_hostrange *head, char * errbuf, int len);
 
 
-int bapp_processmessages(int s, struct queryhash *qh);
+int bapp_processmessages(int s, struct queryhash *qh, int hexdump);
 int bapp_sendmessage(struct queryhash *qh, int s, int retries, int xdelay, int sdelay, int pass_delay);
 #define MAX_RECV_PACKET 1600
 #define RETRIES_MAX 126
